@@ -240,7 +240,7 @@ class Player(game.ChessPlayer):
                 # If unexpected then AI has died
                 if pid == self.__pid and self.__fromEngineFd != None:
                     print 'Monitor died'
-                    self.die()
+                    self._die()
         signal.signal(signal.SIGCHLD, cDied)
 
         # Fork off a child process to manage the engine
@@ -312,11 +312,11 @@ class Player(game.ChessPlayer):
                 data = os.read(self.__fromEngineFd, 256)
             except OSError, e:
                 print 'Error reading from chess engine: ' + str(e)
-                self.die()
+                self._die()
                 return False
             if len(data) == 0:
                 print 'Engine has died'
-                self.die()
+                self._die()
                 return False
             self.connection.registerIncomingData(data)
 
@@ -339,8 +339,9 @@ class Player(game.ChessPlayer):
         
         # Send quit
         try:
-            os.write(fd, '\nquit\n') # FIXME: CECP specific
-        except:
+            if fd is not None:
+                os.write(fd, '\nquit\n') # FIXME: CECP specific
+        except OSError:
             return
 
     # Extended methods
@@ -372,6 +373,10 @@ class Player(game.ChessPlayer):
     def onGameEnded(self, game):
         """Called by game.ChessPlayer"""
         self.quit()
+        
+    def _die(self):
+        self.quit()
+        self.die()
 
     def _runEngine(self, toEngineFd, fromEngineFd):
         # Make the engine low priority for CPU usage
@@ -422,7 +427,7 @@ class Player(game.ChessPlayer):
                  toEngineInput, fromEngineOutput)
                  
         try:
-            while True:                
+            while True:
                 # Wait for data
                 (rfds, _, xfds) = select.select(inputPipes, [], pipes, None)
                 
