@@ -420,14 +420,13 @@ class ChessGame:
         if not self.__blackPlayer.isAlive:
             self.killPlayer(self.__blackPlayer)
             return
-        
-        # Stop if game ended on loaded moves
-        if self.result != RESULT_IN_PROGRESS:
-            self._notifyEndGame()
-            return
 
         self.startLock()
         
+        # Inform other players of the result
+        for player in self.__players:
+            player.onPlayerStartTurn(self.__currentPlayer)
+
         # Get the next player to move
         if self.result == RESULT_IN_PROGRESS:
             self.__currentPlayer._setReadyToMove(True)
@@ -683,12 +682,9 @@ class ChessGame:
         self.result = result
         self.rule = rule
         if self.isStarted():
-            self._notifyEndGame()
-
-    def _notifyEndGame(self):
-        self.__currentPlayer._setReadyToMove(False)
-        for player in self.__players:
-            player.onGameEnded(self)
+            self.__currentPlayer._setReadyToMove(False)
+            for player in self.__players:
+                player.onGameEnded(self)
 
     def getMoves(self):
         """
