@@ -292,26 +292,12 @@ class ChessGame(game.ChessGame):
 
     def save(self):
         """Save this game"""
+        if len(self.getMoves()) < 2:
+            return
         pgnGame = chess.pgn.PGNGame()
         self.toPGN(pgnGame)
-        if self.inHistory:
-            # Don't bother if haven't made any significant moves
-            if len(self.getMoves()) < 2:
-                return
-            self.application.history.save(pgnGame, self.fileName)
-        else:
-            try:
-                f = file(self.fileName, 'w')
-                lines = pgnGame.getLines()
-                for line in lines:
-                    f.write(line + '\n')
-                f.write('\n')
-                f.close()
-            except IOError, e:
-                return e.args[1]
-
+        self.application.history.save(pgnGame, self.fileName)
         self.setNeedsSaving(False)
-        self.application.logger.addLine('Saved game %s to %s' % (repr(self.name), self.fileName))
         
 class UI(ui.UIFeedback):
     """
@@ -392,7 +378,7 @@ class UI(ui.UIFeedback):
         try:
             p = chess.pgn.PGN(path, 1)
         except chess.pgn.Error, e:
-            return e.message
+            return e.description
         except IOError, e:
             return e.strerror
         
@@ -442,7 +428,7 @@ class Application:
         
         self.history = history.GameHistory()
         
-        self.logger = self.ui.controller.addLogWindow('Application Log', '', '')
+        self.logger = self.ui.controller.addLogWindow(_('Application Log'), '', '')
 
     def addAIProfile(self, profile):
         """Add a new AI profile into glChess.
@@ -469,8 +455,10 @@ class Application:
     def watchAIPlayer(self, p):
         """
         """
-        self.ioHandlers[p.fileno()] = p
-        self.ui.controller.watchFileDescriptor(p.fileno())
+        fd = p.fileno()
+        if fd is not None:
+            self.ioHandlers[fd] = p
+            self.ui.controller.watchFileDescriptor(fd)
 
     def unwatchAIPlayer(self, p):
         """
@@ -743,11 +731,11 @@ class Application:
 
     def __autoload(self):
         """Restore games from the autosave file"""
-        (pgnGame, fileName, inHistory) = self.history.getUnfinishedGame()
+        (pgnGame, fileName) = self.history.getUnfinishedGame()
         if pgnGame is not None:
             g = self.addPGNGame(pgnGame, fileName)
             if g is not None:
-                g.inHistory = inHistory
+                g.inHistory = True
 
 if __name__ == '__main__':
     app = Application()
